unit Main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ComCtrls, Buttons, ExtCtrls;

type
  TMainForm = class(TForm)
    Page: TPageControl;
    TabConfig: TTabSheet;
    TabSays: TTabSheet;
    TabLicense: TTabSheet;
    TabVersion: TTabSheet;
    MemSays: TMemo;
    MemLicense: TMemo;
    MemVersion: TMemo;
    TabResult: TTabSheet;
    MemResult: TMemo;
    OpenDialog: TOpenDialog;
    PnlConfig: TPanel;
    BtnUpxPath: TBitBtn;
    CheckAutoQuit: TCheckBox;
    RadioDefault: TRadioButton;
    RadioBest: TRadioButton;
    RadioBrute: TRadioButton;
    RadioUltra: TRadioButton;
    Label1: TLabel;
    Label2: TLabel;
    Button1: TButton;
    EditUpxPath: TEdit;
    CheckSaveLog: TCheckBox;
    BitBtn1: TBitBtn;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure PageChange(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure BtnUpxPathClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure BitBtn1Click(Sender: TObject);
  private
    FUpxRunning: Boolean;
    function GetUpxParam(): String;
    procedure SendUpx(const AParam1, AParam2: String; AStrings: TStrings);
    procedure PutLogFile();
  public
    { Public 錾 }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.dfm}

uses
    Info, GrabConsole;


//-----------------------------------------------------------------------------
//  UPXp̈kp[^
function TMainForm.GetUpxParam(): String;
begin
    if (RadioBest.Checked) then Result := '--best'
    else
    if (RadioBrute.Checked) then Result := '--brute'
    else
    if (RadioUltra.Checked) then Result := '--ultra-brute'
    else
    Result := '';
end;

//-----------------------------------------------------------------------------
//  UPXɃR}hM
procedure TMainForm.SendUpx(const AParam1, AParam2: String; AStrings: TStrings);
var
    LCommand: String;
begin
    SetCurrentDir(ExtractFilePath(ParamStr(0)));
    if (FileExists(EditUpxPath.Text)) then
    begin
        LCommand := Format('%s %s %s', [
                        Quote(EditUpxPath.Text),
                        Quote(AParam1),
                        Quote(AParam2)]);
        PipeConsole(LCommand, AStrings, AStrings);
    end;
end;

//-----------------------------------------------------------------------------
//  Oo
procedure TMainForm.PutLogFile();
var
    i: Integer;
begin
    for i := 0 to MemResult.Lines.Count - 1 do
    begin
        PutLog(ChangeFileExt(ParamStr(0), '.log'), MemResult.Lines.Strings[i]);
    end;
end;

//-----------------------------------------------------------------------------
//  N
procedure TMainForm.FormCreate(Sender: TObject);
begin
    FUpxRunning := False;
    LoadPropertyFromFile(ChangeFileExt(ParamStr(0), '.ini'), Self);
    MemSays.Tag := 0;
    MemLicense.Tag := 0;
    MemVersion.Tag := 0;
end;

//-----------------------------------------------------------------------------
//  I
procedure TMainForm.FormDestroy(Sender: TObject);
begin
    SavePropertyToFile(ChangeFileExt(ParamStr(0), '.ini'), Self);
end;

//-----------------------------------------------------------------------------
//  o[W\
procedure TMainForm.Button1Click(Sender: TObject);
begin
    OpenInfoForm();
end;

//-----------------------------------------------------------------------------
//  y[W؂ւ
procedure TMainForm.PageChange(Sender: TObject);
begin
    if (Page.ActivePage = TabSays) and (MemSays.Tag = 0) then
    begin
        MemSays.Tag := 1;
        SendUpx('', '', MemSays.Lines);
    end
    else
    if (Page.ActivePage = TabLicense) and (MemLicense.Tag = 0) then
    begin
        MemLicense.Tag := 1;
        SendUpx('-L', '', MemLicense.Lines);
    end
    else
    if (Page.ActivePage = TabVersion) and (MemVersion.Tag = 0) then
    begin
        MemVersion.Tag := 1;
        SendUpx('-V', '', MemVersion.Lines);
    end;
end;

//-----------------------------------------------------------------------------
//  UPX ̃pXύX
procedure TMainForm.BtnUpxPathClick(Sender: TObject);
var
    LBase: String;
begin
    LBase := IncludeTrailingPathDelimiter(ExtractFilePath(ParamStr(0)));
    OpenDialog.InitialDir := LBase;
    if (OpenDialog.Execute()) then
    begin
        EditUpxPath.Text := '.\'
                          + ExtractRelativePath(LBase, OpenDialog.FileName);
        MemSays.Tag := 0;
        MemSays.Clear();
        MemLicense.Tag := 0;
        MemLicense.Clear();
        MemVersion.Tag := 0;
        MemVersion.Clear();
    end;
end;

//-----------------------------------------------------------------------------
//  t@ChbvkJn
procedure TMainForm.FormShow(Sender: TObject);
var
    i: Integer;
    LPath: String;
    LParam: String;
    LTitle: String;
    LDiff: Cardinal;
begin
    Self.OnShow := nil;
    if (ParamCount = 0) then Exit;

    FUpxRunning := True;
    PnlConfig.Enabled := False;

    //  k
    LParam := GetUpxParam();
    LTitle := Application.Title;
    Application.Title := Format('%s(%d/%d)', [LTitle, 0, ParamCount]);
    for i := 1 to ParamCount do
    begin
        LPath := ParamStr(i);
        if (FileExists(LPath)) then
        begin
            MemResult.Lines.Add(StringOfChar('=', 80));
            LDiff := GetTickCount();
            MemResult.Lines.Add('[START] ' + FormatDateTime('yyyy/mm/dd hh:nn:ss', Now()));
            SendUpx(LParam, LPath, MemResult.Lines);
            LDiff := GetTickCount() - LDiff;
            MemResult.Lines.Add('[ END ] ' + FormatDateTime('yyyy/mm/dd hh:nn:ss', Now()) + Format('(%d msec)', [LDiff]));
        end;
        Application.Title := Format('%s(%d/%d)', [LTitle, i, ParamCount]);
    end;

    //  Oo
    if (CheckSaveLog.Checked) then
    begin
        PutLogFile();
    end;

    PnlConfig.Enabled := True;
    FUpxRunning := False;

    //  I
    if (CheckAutoQuit.Checked) then
    begin
        PostMessage(Handle, WM_Close, 0, 0);
    end
    else
    begin
        Page.ActivePage := TabResult;
        BringWindowToFront(Application.MainForm.Handle);
    end;
end;

//-----------------------------------------------------------------------------
//  gB
procedure TMainForm.BitBtn1Click(Sender: TObject);
var
    LText: String;
begin
    LText := '(ȏp͖Ȃœ{)'
     + #13#10
     + #13#10'1.kɂ͋NɃACRɃt@ChbvB'
     + #13#10'2.ݒύXɂ͋NB(̏Ԃł͈kł܂)'
     + #13#10
     + #13#10'obNAbvIvV͂܂B'
     + #13#10'NtH_ ini log t@C܂B'
     ;
    AppMessageBox(LText, MB_OK or MB_ICONINFORMATION);
end;

end.
